@@ -4,7 +4,8 @@ use SQL::Statement;
 
 die "DBM is not yet supported!\n" unless $ENV{DBO_ALLOW_DBM};
 
-package DBIx::DBO::DBD::DBM::Handle;
+package # hide from PAUSE
+    DBIx::DBO::DBD::DBM;
 use DBIx::DBO::Common;
 
 sub _bless_dbo {
@@ -18,9 +19,8 @@ sub _bless_dbo {
 sub _get_table_schema {
     my $me = shift;
     my $schema = shift; # Not used
-    my $table = my $q_table = shift;
+    my $table = shift;
     ouch 'No table name supplied' unless defined $table and length $table;
-
     return;
 }
 
