@@ -5,29 +5,60 @@ use Devel::Peek 'SvREFCNT';
 use strict;
 use warnings;
 
-=head2 config
+=head1 NAME
 
-  $table_setting = $dbo->config($option)
-  $dbo->config($option => $table_setting)
+DBIx::DBO::Query - An OO interface to SQL queries and results.  Encapsulates an entire query in an object.
 
-Get or set the global or dbo config settings.
-When setting an option, the previous value is returned.
+=head1 SYNOPSIS
+
+  # Create a Query object by JOINing 2 tables
+  my $query = $dbo->query('my_table', 'my_other_table');
+
+  # Get the Table objects from the query
+  my ($table1, $table2) = $query->tables;
+
+  # Add a JOIN ON clause
+  $query->join_on($table1 ** 'login', '=', $table2 ** 'username');
+
+  # Find our ancestors, and order by age (oldest first)
+  $query->where('name', '=', 'Adam');
+  $query->where('name', '=', 'Eve');
+  $query->order_by({ COL => 'age', ORDER => 'DESC' });
+
+  # New Query using a LEFT JOIN
+  ($query, $table1) = $dbo->query('my_table');
+  $table2 = $query->join_table('another_table', 'LEFT');
+  $query->join_on($table1 ** 'parent_id', '=', $table2 ** 'child_id');
+
+  # Find those not aged between 20 and 30.
+  $query->where($table1 ** 'age', '<', 20, FORCE => 'OR'); # Force OR so that we get: (age < 20 OR age > 30)
+  $query->where($table1 ** 'age', '>', 30, FORCE => 'OR'); # instead of the default: (age < 20 AND age > 30)
+
+=head1 METHODS
+
+=head2 dbh
+
+The read-write C<DBI> handle.
+
+=head2 rdbh
+
+The read-only C<DBI> handle, or if there is no read-only connection, the read-write C<DBI> handle.
+
+=head2 do
+
+  $dbo->do($statement)         or die $dbo->dbh->errstr;
+  $dbo->do($statement, \%attr) or die $dbo->dbh->errstr;
+  $dbo->do($statement, \%attr, @bind_values) or die ...
+
+This provides access to L<DBI-E<gt>do|DBI/"do"> method. It defaults to using the read-write C<DBI> handle.
 
 =cut
 
-sub config {
-    my $me = shift;
-    my $opt = shift;
-    my $val = $me->{Config}{$opt} // $me->{DBO}->config($opt);
-    $me->{Config}{$opt} = shift if @_;
-    return $val;
-}
-
 sub _new {
     my $proto = shift;
     my $class = ref($proto) || $proto;
     my $me = { DBO => shift, sql => undef };
-    blessed $me->{DBO} and $me->{DBO}->isa('DBIx::DBO::Handle') or ouch 'Invalid DBO Object';
+    blessed $me->{DBO} and $me->{DBO}->isa('DBIx::DBO') or ouch 'Invalid DBO Object';
     ouch 'No table specified in new Query' unless @_;
     bless $me, $class;
 
@@ -35,7 +66,7 @@ sub _new {
         $me->join_table($table);
     }
     $me->_blank;
-    return wantarray ? ($me, $me->_tables) : $me;
+    return wantarray ? ($me, $me->tables) : $me;
 }
 
 =head2 join_table
@@ -44,10 +75,10 @@ sub _new {
   $query->join_table([$schema, $table], $join_type);
   $query->join_table($table_object, $join_type);
 
-Join a new table object for the table specified to this query.
+Join a table onto the query, creating a L<DBIx::DBO::Table|DBIx::DBO::Table> object if needed.
 This will perform a comma (", ") join unless $join_type is specified.
 
-Returns the table object.
+Returns the C<Table> object.
 
 =cut
 
@@ -77,7 +108,13 @@ sub join_table {
     return $tbl;
 }
 
-sub _tables {
+=head2 tables
+
+Return a list of L<DBIx::DBO::Table|DBIx::DBO::Table> objects for this query.
+
+=cut
+
+sub tables {
     my $me = shift;
     @{$me->{Tables}};
 }
@@ -143,7 +180,7 @@ sub show {
   $query->join_on($table2, $table1 ** 'id', '=', $table2 ** 'id');
 
 Join tables on a specific WHERE clause. The first argument is the table object being joined onto.
-Then a join on condition follows.
+Then a JOIN ON condition follows, which uses the same arguments as L</where>.
 
 =cut
 
@@ -176,18 +213,19 @@ sub join_on {
 
 =head2 where
 
+Restrict the query with the condition specified (WHERE clause).
+
   $query->where($expression1, $operator, $expression2);
   $query->where($table1 ** 'id', '=', $table2 ** 'id');
 
-Restrict the query with the condition specified (WHERE clause).
+C<$operator> is one of: C<'=', '<', 'E<gt>', 'IN', 'NOT IN', 'BETWEEN', 'NOT BETWEEN', ...>
 
-$operator is one of: '=', '<', '>', 'IN', 'NOT IN', 'BETWEEN', 'NOT BETWEEN', ...
+C<$expression> can be any of the following:
 
-$expression can be any of the following:
-    A SCALAR value: 5 or 'hello'
-    A SCALAR reference: \"22 * 3"  (These are passed unqouted in the SQL statement!)
-    An ARRAY reference: [1, 3, 5]  (Used with IN and BETWEEN etc)
-    A Table Column: $table ** 'id' or $table->column('id')
+    A SCALAR value: C<123> or C<'hello'>
+    A SCALAR reference: C<\"22 * 3">  (These are passed unqouted in the SQL statement!)
+    An ARRAY reference: C<[1, 3, 5]>  (Used with C<IN> and C<BETWEEN> etc)
+    A Table Column: C<$table ** 'id'> or C<$table->column('id')>
     A Hash reference: (Described below)
 
 For a more complex where clause the expression can be passed as a hash reference.
@@ -342,12 +380,23 @@ sub _parse_col_val {
     my $me = shift;
     my $col = shift;
     return $me->_parse_val($col, 'Column') if ref $col;
-    for my $tbl ($me->_tables) {
+    for my $tbl ($me->tables) {
         return [ $tbl->column($col) ] if exists $tbl->{Column_Idx}{$col};
     }
     ouch 'No such column: '.$col;
 }
 
+=head2 group_by
+
+  $query->group_by('column', ...);
+  $query->group_by($table ** 'column', ...);
+  $query->group_by({ COL => $table ** 'column', ORDER => 'DESC' }, ...);
+
+Group the results by the column(s) listed. This will replace the GROUP BY clause.
+To remove the GROUP BY clause simply call C<group_by> without any columns.
+
+=cut
+
 sub group_by {
     my $me = shift;
     undef $me->{sql};
@@ -359,6 +408,17 @@ sub group_by {
     }
 }
 
+=head2 order_by
+
+  $query->order_by('column', ...);
+  $query->order_by($table ** 'column', ...);
+  $query->order_by({ COL => $table ** 'column', ORDER => 'DESC' }, ...);
+
+Order the results by the column(s) listed. This will replace the ORDER BY clause.
+To remove the ORDER BY clause simply call C<order_by> without any columns.
+
+=cut
+
 sub order_by {
     my $me = shift;
     undef $me->{sql};
@@ -376,8 +436,8 @@ sub order_by {
   $query->limit($rows);
   $query->limit($rows, $offset);
 
-Limit the maximum number of rows returned to $rows, optionally skipping the first $offset rows.
-When called without arguments or if $rows is undefined, the limit is removed.
+Limit the maximum number of rows returned to C<$rows>, optionally skipping the first C<$offset> rows.
+When called without arguments or if C<$rows> is undefined, the limit is removed.
 
 =cut
 
@@ -396,7 +456,7 @@ sub limit {
   $query->arrayref(\%attr);
 
 Run the query using L<DBI-E<gt>selectall_arrayref|DBI/"selectall_arrayref"> which returns the result as an arrayref.
-You can specify a slice by including a 'Slice' or 'Columns' attribute in \%attr - See L<DBI-E<gt>selectall_arrayref|DBI/"selectall_arrayref">.
+You can specify a slice by including a 'Slice' or 'Columns' attribute in C<%attr> - See L<DBI-E<gt>selectall_arrayref|DBI/"selectall_arrayref">.
 
 =cut
 
@@ -432,7 +492,7 @@ sub hashref {
   $query->col_arrayref;
   $query->col_arrayref(\%attr);
 
-Run the query using L<DBI-E<gt>selectcol_arrayref|DBI/"selectcol_arrayref"> which returns the result as an arrayref of the values of each row in one array. By default it pushes all the columns requested by the L<show> method onto the result array (this differs from the DBI). To specify which columns to include in the result use the 'Columns' attribute in %attr - see L<DBI-E<gt>selectcol_arrayref|DBI/"selectcol_arrayref">.
+Run the query using L<DBI-E<gt>selectcol_arrayref|DBI/"selectcol_arrayref"> which returns the result as an arrayref of the values of each row in one array. By default it pushes all the columns requested by the L</show> method onto the result array (this differs from the C<DBI>). Or to specify which columns to include in the result use the 'Columns' attribute in C<%attr> - see L<DBI-E<gt>selectcol_arrayref|DBI/"selectcol_arrayref">.
 
 =cut
 
@@ -455,7 +515,8 @@ sub col_arrayref {
   my $row = $query->fetch;
 
 Fetch the next row from the query. This will run/rerun the query if needed.
-Returns a DBIx::DBO::Row object or undefined if there are no more rows.
+
+Returns a L<DBIx::DBO::Row|DBIx::DBO::Row> object or undefined if there are no more rows.
 
 =cut
 
@@ -484,8 +545,7 @@ sub fetch {
 
   my $row = $query->row;
 
-Returns the DBIx::DBO::Row object for the current row from the query
-or an empty DBIx::DBO::Row object if there is no current row.
+Returns the L<DBIx::DBO::Row|DBIx::DBO::Row> object for the current row from the query or an empty L<DBIx::DBO::Row|DBIx::DBO::Row> object if there is no current row.
 
 =cut
 
@@ -586,9 +646,7 @@ sub count_rows {
   $query->config(CalcFoundRows => 1); # Only applicable to MySQL
   my $total_rows = $query->found_rows;
 
-Return the number of rows that would have been returned if there was no limit clause.
-Before runnning the query the 'CalcFoundRows' config option can be enabled for improved
-performance on supported databases.
+Return the number of rows that would have been returned if there was no limit clause.  Before runnning the query the C<CalcFoundRows> config option can be enabled for improved performance on supported databases.
 
 Returns undefined if there is an error or is unable to determine the number of found rows.
 
@@ -608,7 +666,7 @@ sub found_rows {
 
   my $sth = $query->sth;
 
-Reutrns the DBI statement handle from the query.
+Reutrns the C<DBI> statement handle from the query.
 This will run/rerun the query if needed.
 
 =cut
@@ -624,7 +682,7 @@ sub sth {
 
   $query->finish;
 
-Calls DBI finish on the statement handle if it is active.
+Calls L<DBI-E<gt>finish|DBI/"finish"> on the statement handle, if it's active.
 
 =cut
 
@@ -668,6 +726,24 @@ sub _build_sql {
     $me->{sql} = $me->_build_sql_select($me->{build_data});
 }
 
+=head2 config
+
+  $query_setting = $dbo->config($option)
+  $dbo->config($option => $query_setting)
+
+Get or set this C<DBIx::DBO::Query> config settings.
+When setting an option, the previous value is returned.
+
+=cut
+
+sub config {
+    my $me = shift;
+    my $opt = shift;
+    my $val = $me->{Config}{$opt} // $me->{DBO}->config($opt);
+    $me->{Config}{$opt} = shift if @_;
+    return $val;
+}
+
 sub DESTROY {
     undef %{$_[0]};
 }
